execline: the unexport command
Keywords: execline command unexport environment

execline
Software
skarnet.org

# The `unexport` program

`unexport` removes a variable from the environment, then executes a program.

## Interface

         unexport var prog...

`unexport` removes the var variable from the environment, then execs into prog with its arguments.

## Notes

- Unsetting var is quite different from setting it to an empty value. Shell scripts usually won't make the distinction; execline does.